@@ -1,5 +1,6 @@
 library(randtoolbox)
 
+n <- 5
 
 #### n argument ####
 try(sobol(-1))
@@ -9,26 +10,26 @@ try(sobol(1, 0))
 
 
 #### init argument ####
-sobol(5)
+sobol(n)
 randtoolbox:::.getrandtoolboxEnv(".sobol.seed")
-sobol(5, init=TRUE)
+sobol(n, init=TRUE)
 randtoolbox:::.getrandtoolboxEnv(".sobol.seed")
-sobol(5, init=FALSE)
+sobol(n, init=FALSE)
 try(sobol(5, init="a"))
 
 #### mixed argument ####
 
 try(sobol(1, mixed=3))
-sobol(3, mixed=TRUE)
+sobol(n, mixed=TRUE)
 
 #### normal argument ####
-sobol(3, normal=TRUE)
+sobol(n, normal=TRUE)
 try(sobol(3, normal=1))
 
 
 #### start argument ####
 try(sobol(3, start="3"))
-sobol(5, start=0)
-sobol(5, start=1)
+sobol(n, start=0)
+sobol(n, start=1)
 
 
